@@ -1,5 +1,5 @@
-magaxis<-
-function(side=1:4, majorn=5, minorn=5, tcl=0.5, ratio=0.5, labels=TRUE, unlog='Auto', tline=0.5, mtline=2, xlab=NULL, ylab=NULL, box=FALSE, crunch=TRUE, logpretty=TRUE, prettybase=10, hersh=FALSE, family='sans',...){
+magaxis <-
+function(side=1:2, majorn=5, minorn=5, tcl=0.5, ratio=0.5, labels=TRUE, unlog='Auto', mgp=c(2,0.5,0), mtline=2, xlab=NULL, ylab=NULL, crunch=TRUE, logpretty=TRUE, prettybase=10, hersh=FALSE, family='sans', frame.plot=FALSE, usepar=FALSE, ...){
 majornlist=majorn
 minornlist=minorn
 unloglist=unlog
@@ -32,6 +32,11 @@ if(hersh & family=='sans'){par(family='HersheySans')}
 if(hersh==F & family=='serif'){par(family='serif')}
 if(hersh==F & family=='sans'){par(family='sans')}
 
+if(usepar){
+  tcl=par()$tcl
+  mgp=par()$mgp
+}
+
 for(i in 1:length(side)){
 		currentside=side[i]
     majorn=majornlist[i]
@@ -76,12 +81,12 @@ for(i in 1:length(side)){
   		minors = pretty(major.ticks[1:2],minorn+2)-major.ticks[1]
  		}
 
- 		if(logged){axis(side=currentside,at=10^major.ticks,tcl=tcl,labels=FALSE,mgp=c(2,tline,0),...)}
- 		else axis(side=currentside,at=major.ticks,tcl=tcl,labels=FALSE,mgp=c(2,tline,0),...)
+ 		if(logged){axis(side=currentside,at=10^major.ticks,tcl=tcl,labels=FALSE,mgp=mgp,...)}
+ 		else axis(side=currentside,at=major.ticks,tcl=tcl,labels=FALSE,mgp=mgp,...)
  		
   		if(labels){
-  		    if(logged){axis(side=currentside,at=10^labloc,tick=F,labels=uselabels,mgp=c(2,tline,0),...)}
-  		    else axis(side=currentside,at=labloc,tick=F,labels=uselabels,mgp=c(2,tline,0),...)
+  		    if(logged){axis(side=currentside,at=10^labloc,tick=F,labels=uselabels,mgp=mgp,...)}
+  		    else axis(side=currentside,at=labloc,tick=F,labels=uselabels,mgp=mgp,...)
   		}
   		
   		if(usemultloc==F){
@@ -93,6 +98,6 @@ for(i in 1:length(side)){
     if(is.null(xlab)==F & currentside==1){mtext(xlab,1,line=mtline)}
     if(is.null(ylab)==F & currentside==2){mtext(ylab,2,line=mtline)}  
 }
-if(box){box()}
+if(frame.plot){box()}
 par(family=currentfamily)
 }
